<!--排查单位查询-筛选弹层-->
<template>
  <van-popup
    v-model="isShowPopup"
    :close-on-click-overlay="false"
    position="right"
    :style="{ width:'100%',height: '100%' }"
    @open="open"
    @closed="closed"
  >

    <div class="details-container">
      <!--  头部  -->
      <van-sticky>
        <van-nav-bar
          title="详情"
          left-arrow
          @click-left="_ => $emit('update:isShow', false)"
        />
      </van-sticky>

      <van-form
        label-width="auto"
      >
        <van-collapse v-model="activeNames">
          <van-collapse-item
            title="安全工作目标信息"
            name="1"
            icon="more-o"
          >
            <van-field
              label="目标年度"
              input-align="right">
              <template #input>
                {{ formData.targetYear || '-' }}
              </template>
            </van-field>
            <van-field
              name="name"
              label="目标名称"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.name"
              readonly
            />
            <van-field
              label="安全业务分类"
              input-align="right">
              <template #input>
                {{ dictionaryEscape(saftyClassOpt, formData.saftyClass) || '-' }}
              </template>
            </van-field>
            <van-field
              label="是否考核"
              input-align="right"
            >
              <template #input>
                {{ formData.targetIsCheck || '-' }}
              </template>
            </van-field>
            <van-field
              name="content"
              label="目标说明"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.content"
              readonly
            />
            <van-field
              name="according"
              label="相关依据描述"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.according"
              readonly
            />
            <van-field
              name="memo"
              label="备注"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.memo"
              readonly
            />
            <van-field
              label="附件"
              label-width="100px"
              name="caseFileArr"
            >
              <template #input>
                <van-uploader
                  v-model="formData.fileListArr"
                />
              </template>
            </van-field>
          </van-collapse-item>
          <van-collapse-item
            title="安全目标考核项"
            name="2"
            icon="comment-circle-o"
          >
            <div class="multiple-box">
              <div class="multiple-box-item" v-for="(item,index) in formData.detail" :key="index">
                <van-field
                  :label="`指标项${index + 1}：`"
                  input-align="right"
                />
                <van-field
                  label="指标项名称"
                  input-align="right">
                  <template #input>
                    {{ item.kpiName || '-' }}
                  </template>
                </van-field>
                <van-field
                  label="标准说明"
                  input-align="right">
                  <template #input>
                    {{ item.kpiStandard || '-' }}
                  </template>
                </van-field>
                <van-field
                  label="考核方式"
                  input-align="right">
                  <template #input>
                    {{
                      dictionaryEscape(checkTypeOpt, item.checkType) || '-'
                    }}
                  </template>
                </van-field>
                <van-field
                  label="得分范围值"
                  input-align="right">
                  <template #input>
                    {{ item.checkScore || '-' }}
                  </template>
                </van-field>
                <van-field
                  label="权重值"
                  input-align="right">
                  <template #input>
                    {{ item.checkWeight || '-' }}
                  </template>
                </van-field>
                <van-field
                  label="排序"
                  input-align="right">
                  <template #input>
                    {{ item.sn || '-' }}
                  </template>
                </van-field>

              </div>
            </div>
          </van-collapse-item>
        </van-collapse>
      </van-form>

      <van-overlay :show="loading">
        <van-loading color="#1989fa" size="24px">详情加载中...</van-loading>
      </van-overlay>
    </div>

  </van-popup>
</template>

<script>
import moment from 'moment'
import CmgtSaftyTargetApi from '@/views/Manage/saftyPlan/api/CmgtSaftyTargetApi'
import {dictionaryEscape} from '@/utils/dictionary'
import dictUtils from '@/components/dict/DictSelectUtils'


export default {
  name: 'DetailsPopup',
  props: {
    // 是否展示弹层
    isShow: {
      default: false,
      type: Boolean
    },
    rowInfo: {
      default: () => ({}),
      type: Object
    },
    saftyClassOpt: {
      default: () => ([]),
      type: Array
    }
  },
  data() {
    return {
      formData: {},
      checkTypeOpt: dictUtils.getDictItemsFromCache('zbkhfs'),
      loading: false,
      activeNames: [] // 手风琴展开数组
    }
  },
  computed: {
    isShowPopup: {
      get() {
        return this.isShow
      },
      set(val) {
        this.$emit('update:isShow', val)
      }
    },
    previewUrl() {
      return window.context.portal + '/file/onlinePreviewController/v1/getFileById_'
    }
  },
  methods: {
    dictionaryEscape,
    moment,

    // 弹层打开
    open() {
      if (this.rowInfo.id) {
        this.loading = true
        CmgtSaftyTargetApi.getItemById(this.rowInfo.id, res => {
          const {fileList = [], ...formData} = res
          this.formData = {
            ...formData,
            fileList: fileList,
            fileListArr: fileList ? fileList.map(item => ({
              name: item.fileName,
              url: this.previewUrl + item.id,
              isImage: true
            })) : []
          }
          this.activeNames = ['1']
          this.loading = false
        })
      }
    },

    // 弹层关闭
    closed() {
      // 重置组件内的数据
      Object.assign(this.$data, this.$options.data.call(this))
    }
  }
}
</script>

<style lang="scss" scoped>
.details-container {
  width: 100%;
  height: 100%;
  background: #fff;
  display: flex;
  flex-direction: column;

  ::v-deep .van-form {
    flex: 1;
    overflow: auto;
    padding-bottom: 40PX;

    .van-uploader__wrapper {
      .van-uploader__upload {
        display: none;
      }

      .van-uploader__preview-delete {
        display: none;
      }
    }
  }


  ::v-deep .van-action-sheet__close {
    display: none;
  }

  ::v-deep .van-collapse-item__content {
    padding: 0 0 0 20PX;
    margin-bottom: 5PX;

    .multiple-box {
      display: flex;
      flex-direction: column;
      row-gap: 10PX;

      .multiple-box-item {
        border: 1px solid #c9c9c9;
        margin-right: 10PX;
      }
    }


  }

  ::v-deep .van-overlay {
    display: flex;
    justify-content: center;
    align-items: center;
  }

}
</style>

